##############################################################################
# Chapter 1                                                                  #
# Sanchez, J. Time Series for Data Scientists, CUP 2023.                     #
# Code used in the Case Study appearing in the book                          #
# Program  # Quandl.R in Base R version                                      #
# Last modified: 1/23/2023                                                   #                                       #
############################################################################## 

install.packages("Quandl")
library(Quandl)

## See W01-1-Appendix lesson for instructions 
## on how to obtain the key that you must enter
## between " " It will be a very long key. 
Quandl.api_key("")

# Access Missouri's unemployment rate from 
#  FRED's database

ts2= Quandl(code="FRED/MOUR",
            type="ts",
            collapse="monthly",
            order="asc",
            end_date="2020-07-01",
            meta=TRUE)
ts2 # not too long so can view whole dataset
head(ts2)
tail(ts2)
class(ts2)
str(ts2)   # View some metadata

#### Base R Time series functions that work with ts()
frequency(ts2)  # frequency of observations: monthly
start(ts2)   # start date is January 1976
end(ts2)     # end date 
time(ts2)   # extract a time variable (perhaps for regression?)
cycle(ts2)   # extract categorical variable for month-for regression?




#### Access California's unemployment 
### rate from FRED's database


ts3= Quandl(code="FRED/CAUR",
            type="ts",
            collapse="monthly",
            order="asc",
            end_date="2020-07-01",
            meta=TRUE)
head(ts3)
tail(ts3)
class(ts3)
str(ts3)

start(ts3)
end(ts3)
ts3  ## View only because it is not too big. 

#### Access the UK unemployment rate from 
## the UK Office of National Statistics 
## database 

ts4= Quandl(code="UKONS/MGSX_M",
            type="ts",
            collapse="monthly",
            order="asc",
            end_date="2020-07-01",
            meta=TRUE)
head(ts4)
tail(ts4)
class(ts4)
str(ts4)
start(ts4)
end(ts4)
ts4 ## View only because it is not too big.


##### Prepare for graph of the three series in one plot



#### Graph in W01-1-Appendix lesson 

plot.ts(ts2,
        ylab="Unemployment rate",
        main="FRED and UKONS unemployment \n data from Quandl's web API",
        ylim=c(1,16),lwd=1.5,cex=0.5,lty=1)
lines(ts3, col="red",lwd=1.5,cex=0.5,lty=2)
lines(ts4, col="blue",lwd=1.5,cex=0.5,lty=6)



legend("topleft", legend = c("MO", "CA", "UK "),
       col = c("black", "red", "blue"),lty=c(1,2,6))

#dev.off()


#### Sometimes, a dygraph helps you see details.

###Using package dygraph to do an interactive graph.

install.packages("dygraphs")
library(dygraphs)
dygraph(ts2,main="MO Unemployment rate",
        ylab="Percentage") %>% dyRangeSelector
